@@ -11,9 +11,9 @@
 
 #include "data_table.h"
 #include "data_row_id.h"
-#include "util/string/utf8stringbuf.h"
-#include "util/string/utf8error.h"
-#include "universal_utf8_writer.h"
+#include "utf8stringbuf/utf8stringbuf.h"
+#include "utf8stringbuf/utf8error.h"
+#include "utf8stream/universal_utf8_writer.h"
 #include "u8/u8_error.h"
 #include <stdint.h>
 #include <stdbool.h>
