@@ -3,8 +3,8 @@
 #include "storage/data_database.h"
 #include "data_id.h"
 #include "data_table.h"
-#include "trace.h"
-#include "tslog.h"
+#include "trace/trace.h"
+#include "tslog/tslog.h"
 #include <unistd.h>
 #include <assert.h>
 
@@ -330,6 +330,22 @@ static const char *DATA_DATABASE_ALTER_DIAGRAMELEMENT_TABLE_UUID =
 static const char *DATA_DATABASE_UPDATE_DIAGRAMELEMENT_UUID =
     "UPDATE diagramelements SET uuid=(SELECT " DATA_DATABASE_CREATE_UUID " WHERE diagramelements.id!=-1) WHERE uuid=\'\';";
 
+/*!
+ *  \brief string constant to start a transaction
+ *
+ *  \see http://sqlite.org/lang.html
+ */
+static const char *DATA_DATABASE_BEGIN_TRANSACTION =
+    "BEGIN TRANSACTION;";
+
+/*!
+ *  \brief string constant to commit a transaction
+ *
+ *  \see http://sqlite.org/lang.html
+ */
+static const char *DATA_DATABASE_COMMIT_TRANSACTION =
+    "COMMIT TRANSACTION;";
+
 u8_error_t data_database_private_initialize_tables( data_database_t *this_ )
 {
     TRACE_BEGIN();
@@ -416,6 +432,7 @@ void data_database_init ( data_database_t *this_ )
     utf8stringbuf_clear( (*this_).db_file_name );
 
     (*this_).is_open = false;
+    (*this_).transaction_recursion = 0;
 
     g_mutex_init ( &((*this_).private_lock) );
 
@@ -429,6 +446,8 @@ u8_error_t data_database_private_open ( data_database_t *this_, const char* db_f
 {
     TRACE_BEGIN();
     assert( NULL != db_file_path );
+    /* there should not be pending transactions when calling open */
+    assert( (*this_).transaction_recursion == 0 );
     int sqlite_err;
     u8_error_t result = U8_ERROR_NONE;
     bool notify_listeners = false;
@@ -514,6 +533,8 @@ u8_error_t data_database_private_open ( data_database_t *this_, const char* db_f
 u8_error_t data_database_close ( data_database_t *this_ )
 {
     TRACE_BEGIN();
+    /* there should not be pending transactions when calling cloas */
+    assert( (*this_).transaction_recursion == 0 );
     int sqlite_err;
     u8_error_t result = U8_ERROR_NONE;
     bool notify_change_listeners = false;
@@ -548,6 +569,7 @@ u8_error_t data_database_close ( data_database_t *this_ )
 
         utf8stringbuf_clear( (*this_).db_file_name );
         (*this_).is_open = false;
+        (*this_).transaction_recursion = 0;
 
         notify_change_listeners = true;
     }
@@ -578,6 +600,8 @@ u8_error_t data_database_close ( data_database_t *this_ )
 void data_database_destroy ( data_database_t *this_ )
 {
     TRACE_BEGIN();
+    /* there should not be pending transactions when calling destroy */
+    assert( (*this_).transaction_recursion == 0 );
 
     data_database_private_clear_db_listener_list( this_ );
     if ( (*this_).is_open )
@@ -586,6 +610,7 @@ void data_database_destroy ( data_database_t *this_ )
     }
     data_change_notifier_destroy( &((*this_).notifier) );
 
+    (*this_).transaction_recursion = 0;
     /* g_mutex_clear ( &((*this_).private_lock) ); -- must not be called because this GMutex is not on the stack */
 
     TRACE_END();
@@ -612,12 +637,16 @@ u8_error_t data_database_flush_caches ( data_database_t *this_ )
                 result = U8_ERROR_AT_DB;
             }
 #else
-            TSLOG_WARNING_INT( "The compile-time version of sqlite3 did not provide the sqlite3_db_cacheflush() function.", SQLITE_VERSION_NUMBER );
+            TSLOG_WARNING_INT( "The compile-time version of sqlite3 did not provide the sqlite3_db_cacheflush() function.",
+                               SQLITE_VERSION_NUMBER
+                             );
 #endif
         }
         else
         {
-            TSLOG_WARNING_INT( "The runtime-time version of sqlite3 does not provide the sqlite3_db_cacheflush() function.", sqlite3_libversion_number() );
+            TSLOG_WARNING_INT( "The runtime-time version of sqlite3 does not provide the sqlite3_db_cacheflush() function.",
+                               sqlite3_libversion_number()
+                             );
         }
     }
 
@@ -747,6 +776,88 @@ u8_error_t data_database_private_notify_db_listeners( data_database_t *this_, da
     return result;
 }
 
+u8_error_t data_database_transaction_begin ( data_database_t *this_ )
+{
+    TRACE_BEGIN();
+    /* nestnig of transactions should not be greater than 2. You may increase this limit if needed. */
+    assert( (*this_).transaction_recursion < 2 );
+    u8_error_t result = U8_ERROR_NONE;
+    int sqlite_err;
+    char *error_msg = NULL;
+    sqlite3 *db = data_database_get_database_ptr( this_ );
+
+    if ( data_database_is_open( this_ ) )
+    {
+        if ( (*this_).transaction_recursion == 0 )
+        {
+            TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_BEGIN_TRANSACTION );
+            sqlite_err = sqlite3_exec( db, DATA_DATABASE_BEGIN_TRANSACTION, NULL, NULL, &error_msg );
+            if ( SQLITE_OK != sqlite_err )
+            {
+                TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_BEGIN_TRANSACTION );
+                TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
+                result |= U8_ERROR_AT_DB;
+            }
+            if ( error_msg != NULL )
+            {
+                TSLOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
+                sqlite3_free( error_msg );
+                error_msg = NULL;
+            }
+        }
+        (*this_).transaction_recursion ++;
+    }
+    else
+    {
+        TSLOG_WARNING_STR( "database not open. cannot execute", DATA_DATABASE_BEGIN_TRANSACTION );
+        result = U8_ERROR_NO_DB;
+    }
+
+    TRACE_END_ERR( result );
+    return result;
+}
+
+u8_error_t data_database_transaction_commit ( data_database_t *this_ )
+{
+    TRACE_BEGIN();
+    /* there should be at least 1 pending transaction */
+    assert( (*this_).transaction_recursion > 0 );
+    u8_error_t result = U8_ERROR_NONE;
+    int sqlite_err;
+    char *error_msg = NULL;
+    sqlite3 *db = data_database_get_database_ptr( this_ );
+
+    if ( data_database_is_open( this_ ) )
+    {
+        if ( (*this_).transaction_recursion == 1 )
+        {
+            TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_COMMIT_TRANSACTION );
+            sqlite_err = sqlite3_exec( db, DATA_DATABASE_COMMIT_TRANSACTION, NULL, NULL, &error_msg );
+            if ( SQLITE_OK != sqlite_err )
+            {
+                TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_COMMIT_TRANSACTION );
+                TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
+                result |= U8_ERROR_AT_DB;
+            }
+            if ( error_msg != NULL )
+            {
+                TSLOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
+                sqlite3_free( error_msg );
+                error_msg = NULL;
+            }
+        }
+        (*this_).transaction_recursion --;
+    }
+    else
+    {
+        TSLOG_WARNING_STR( "database not open. cannot execute", DATA_DATABASE_COMMIT_TRANSACTION );
+        result = U8_ERROR_NO_DB;
+    }
+
+    TRACE_END_ERR( result );
+    return result;
+}
+
 
 /*
 Copyright 2016-2022 Andreas Warnke
