@@ -2,15 +2,15 @@
 
 #include "gui_attributes_editor.h"
 #include "util/gtk_helper/gtk_helper_tree_model.h"
-#include "trace.h"
+#include "trace/trace.h"
 #include "data_table.h"
 #include "data_id.h"
-#include "util/string/utf8string.h"
+#include "utf8stringbuf/utf8string.h"
 #include <gtk/gtk.h>
 #include <stdbool.h>
 #ifndef NDEBUG
-#include "stream/universal_stream_output_stream.h"
-#include "universal_utf8_writer.h"
+#include "u8stream/universal_stream_output_stream.h"
+#include "utf8stream/universal_utf8_writer.h"
 #endif
 
 void gui_attributes_editor_init ( gui_attributes_editor_t *this_,
@@ -1770,6 +1770,7 @@ void gui_attributes_editor_private_type_update_view ( gui_attributes_editor_t *t
 #if ( GTK_MAJOR_VERSION >= 4 )
     /* workaround for https://gitlab.gnome.org/GNOME/gtk/-/issues/4856 */
     gtk_widget_set_size_request( GTK_WIDGET(type_icon_grid), 7*40, 5*30 );
+    //gtk_layout_manager_layout_changed( gtk_widget_get_layout_manager( GTK_WIDGET(type_icon_grid) ));
 #else
 #endif
 
