@@ -7,8 +7,8 @@
 #include "util/geometry/geometry_rectangle.h"
 #include "data_table.h"
 #include "data_id.h"
-#include "trace.h"
-#include "tslog.h"
+#include "trace/trace.h"
+#include "tslog/tslog.h"
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 #include <stdint.h>
@@ -616,8 +616,8 @@ void gui_sketch_area_private_draw_subwidgets ( gui_sketch_area_t *this_, shape_i
     }
 
     /* overlay tool-helper lines */
-    const int32_t mouse_x = gui_sketch_drag_state_get_to_x ( &((*this_).drag_state) );
-    const int32_t mouse_y = gui_sketch_drag_state_get_to_y ( &((*this_).drag_state) );
+    const int32_t mouse_x = gui_sketch_drag_state_get_to_x( &((*this_).drag_state) );
+    const int32_t mouse_y = gui_sketch_drag_state_get_to_y( &((*this_).drag_state) );
     gui_sketch_overlay_draw( &((*this_).overlay),
                              selected_tool,
                              &((*this_).drag_state),
@@ -1073,19 +1073,12 @@ void gui_sketch_area_button_press( gui_sketch_area_t *this_, int x, int y )
             /* update drag state */
             gui_sketch_drag_state_start_dragging_when_move ( &((*this_).drag_state), focused_object );
 
-            /* which object is currently focused? */
-            const data_id_t focused_visible_before = gui_marked_set_get_focused( (*this_).marker );
+            /* toggle objects according to rules of gui_marked_set_t */
+            gui_marked_set_toggle_obj( (*this_).marker, focused_object_visible, diag_id );
 
-            if ( data_id_equals ( &focused_object_visible, &focused_visible_before ) )
+            if ( gui_marked_set_has_focus( (*this_).marker ) )
             {
-                /* the clicked object is already focused */
-                gui_marked_set_toggle_selected_obj( (*this_).marker, focused_object_visible );
-            }
-            else
-            {
-                /* set focused object and notify listener */
-                gui_marked_set_set_focused( (*this_).marker, focused_object_visible, diag_id );
-
+                /* notify listener */
                 data_id_t real_object = focused_object_visible;
                 if ( DATA_TABLE_DIAGRAMELEMENT == data_id_get_table( &real_object ) )
                 {
@@ -1093,6 +1086,11 @@ void gui_sketch_area_button_press( gui_sketch_area_t *this_, int x, int y )
                 }
                 gui_sketch_area_private_notify_listeners( this_, real_object );
             }
+            else
+            {
+                /* notify listener */
+                gui_sketch_area_private_notify_listeners( this_, DATA_ID_VOID );
+            }
 
             /* mark dirty rect */
             gtk_widget_queue_draw( (*this_).drawing_area );
