@@ -1,7 +1,8 @@
 /* File: gui_sketch_overlay.c; Copyright and License: see below */
 
 #include "sketch_area/gui_sketch_overlay.h"
-#include "trace.h"
+#include "sketch_area/gui_sketch_snap_state.h"
+#include "trace/trace.h"
 #include <gtk/gtk.h>
 #include <assert.h>
 
@@ -9,10 +10,10 @@ void gui_sketch_overlay_init( gui_sketch_overlay_t *this_ )
 {
     TRACE_BEGIN();
 
-    (*this_).overlay_std_red = 0.2;
-    (*this_).overlay_std_green = 1.0;
-    (*this_).overlay_std_blue = 0.6;
-    (*this_).overlay_std_alpha = 0.8;
+    (*this_).overlay_std_red = 0.0;
+    (*this_).overlay_std_green = 0.6;
+    (*this_).overlay_std_blue = 0.4;
+    (*this_).overlay_std_alpha = 1.0;
 
     TRACE_END();
 }
@@ -135,66 +136,14 @@ void gui_sketch_overlay_private_draw_edit_mode( gui_sketch_overlay_t *this_,
     {
         if ( NULL != card_under_mouse )
         {
-            universal_bool_list_t is_snapped;
+            /* draw grid line crossings */
+            gui_sketch_overlay_private_draw_grid( this_, card_under_mouse, cr );
+
+            /* draw snap-to-grid indicator */
             const int32_t to_x = gui_sketch_drag_state_get_to_x ( drag_state );
             const int32_t to_y = gui_sketch_drag_state_get_to_y ( drag_state );
-            is_snapped = gui_sketch_card_is_pos_on_grid ( card_under_mouse, to_x, to_y );
-
-            cairo_set_source_rgba( cr,
-                                   (*this_).overlay_std_red,
-                                   (*this_).overlay_std_green,
-                                   (*this_).overlay_std_blue,
-                                   (*this_).overlay_std_alpha
-                                 );
-            if ( universal_bool_list_get_first ( &is_snapped ) )
-            {
-                cairo_move_to ( cr, to_x, to_y-60 );
-                cairo_line_to ( cr, to_x, to_y-20 );
-                cairo_move_to ( cr, to_x, to_y+20 );
-                cairo_line_to ( cr, to_x, to_y+60 );
-                cairo_stroke (cr);
-            }
-            if ( universal_bool_list_get_second ( &is_snapped ) )
-            {
-                cairo_move_to ( cr, to_x-60, to_y );
-                cairo_line_to ( cr, to_x-20, to_y );
-                cairo_move_to ( cr, to_x+20, to_y );
-                cairo_line_to ( cr, to_x+60, to_y );
-                cairo_stroke (cr);
-            }
-
-            /* draw lines */
-            const data_diagram_t *diag = gui_sketch_card_get_diagram_const ( card_under_mouse );
-            const data_diagram_type_t diag_type = data_diagram_get_diagram_type( diag );
-            if (( diag_type != DATA_DIAGRAM_TYPE_UML_SEQUENCE_DIAGRAM )
-                && ( diag_type != DATA_DIAGRAM_TYPE_UML_TIMING_DIAGRAM )
-                && ( diag_type != DATA_DIAGRAM_TYPE_LIST ))
-            {
-                shape_int_rectangle_t bounds;
-                uint32_t x_count;
-                uint32_t y_count;
-                gui_sketch_card_get_grid_area( card_under_mouse, &bounds, &x_count, &y_count );
-                for ( uint32_t x_idx = 0; x_idx < x_count; x_idx ++ )
-                {
-                    for ( uint32_t y_idx = 0; y_idx < y_count; y_idx ++ )
-                    {
-                        const int32_t x = shape_int_rectangle_get_left(&bounds)
-                                          + (( shape_int_rectangle_get_width(&bounds) * x_idx )/( x_count-1 ));
-                        const int32_t y = shape_int_rectangle_get_top(&bounds)
-                                          + (( shape_int_rectangle_get_height(&bounds) * y_idx )/( y_count-1 ));
-                        static const int32_t HALF_LINE = 4;
-                        cairo_move_to ( cr, x-HALF_LINE, y );
-                        cairo_line_to ( cr, x+HALF_LINE, y );
-                        cairo_move_to ( cr, x, y-HALF_LINE );
-                        cairo_line_to ( cr, x, y+HALF_LINE );
-                        cairo_stroke (cr);
-                    }
-                }
-            }
-            else
-            {
-                /* no x/y grid for seq, timing and list diagrams*/
-            }
+            const gui_sketch_snap_state_t snapped = gui_sketch_card_is_pos_on_grid ( card_under_mouse, to_x, to_y );
+            gui_sketch_overlay_private_draw_snap_indicator( this_, card_under_mouse, snapped, to_x, to_y, cr );
         }
     }
 
@@ -298,11 +247,24 @@ void gui_sketch_overlay_private_draw_create_mode( gui_sketch_overlay_t *this_,
     {
         if ( NULL != card_under_mouse )
         {
-            const bool draw_arrow 
+            const bool draw_arrow
                 = (( highlighted_object_table == DATA_TABLE_CLASSIFIER )
                 ||( highlighted_object_table == DATA_TABLE_FEATURE )
                 ||( highlighted_object_table == DATA_TABLE_DIAGRAMELEMENT ));
-            
+
+            /* draw grid */
+            if ( ! draw_arrow )
+            {
+                /* draw grid line crossings */
+                gui_sketch_overlay_private_draw_grid( this_, card_under_mouse, cr );
+
+                /* draw snap-to-grid indicator */
+                const int32_t to_x = gui_sketch_drag_state_get_to_x ( drag_state );
+                const int32_t to_y = gui_sketch_drag_state_get_to_y ( drag_state );
+                const gui_sketch_snap_state_t snapped = gui_sketch_card_is_pos_on_grid( card_under_mouse, to_x, to_y );
+                gui_sketch_overlay_private_draw_snap_indicator( this_, card_under_mouse, snapped, to_x, to_y, cr );
+            }
+
             /* get coordinates */
             const int32_t cur_x = gui_sketch_drag_state_get_to_x ( drag_state );
             const int32_t cur_y = gui_sketch_drag_state_get_to_y ( drag_state );
@@ -358,6 +320,102 @@ void gui_sketch_overlay_private_draw_create_mode( gui_sketch_overlay_t *this_,
     TRACE_END();
 }
 
+void gui_sketch_overlay_private_draw_grid( gui_sketch_overlay_t *this_,
+                                           const gui_sketch_card_t *card_under_mouse,
+                                           cairo_t *cr )
+{
+    TRACE_BEGIN();
+    assert( NULL != card_under_mouse );
+    assert( NULL != cr );
+
+    cairo_set_source_rgba( cr,
+                           (*this_).overlay_std_red,
+                           (*this_).overlay_std_green,
+                           (*this_).overlay_std_blue,
+                           (*this_).overlay_std_alpha
+                         );
+
+    /* draw grid */
+    const data_diagram_t *diag = gui_sketch_card_get_diagram_const ( card_under_mouse );
+    const data_diagram_type_t diag_type = data_diagram_get_diagram_type( diag );
+    if (( diag_type != DATA_DIAGRAM_TYPE_UML_SEQUENCE_DIAGRAM )
+        && ( diag_type != DATA_DIAGRAM_TYPE_UML_TIMING_DIAGRAM )
+        && ( diag_type != DATA_DIAGRAM_TYPE_LIST ))
+    {
+        shape_int_rectangle_t bounds;
+        uint32_t x_count;
+        uint32_t y_count;
+        gui_sketch_card_get_grid_area( card_under_mouse, &bounds, &x_count, &y_count );
+        assert( x_count >= 2 );
+        assert( y_count >= 2 );
+        const int32_t left = shape_int_rectangle_get_left(&bounds);
+        const int32_t top = shape_int_rectangle_get_top(&bounds);
+        const int32_t width = shape_int_rectangle_get_width(&bounds);
+        const int32_t height = shape_int_rectangle_get_height(&bounds);
+        for ( uint32_t x_idx = 1; (x_idx+1) < x_count; x_idx ++ )
+        {
+            for ( uint32_t y_idx = 1; (y_idx+1) < y_count; y_idx ++ )
+            {
+                const int32_t x = left + (( width * x_idx )/( x_count-1 ));
+                const int32_t y = top + (( height * y_idx )/( y_count-1 ));
+                static const int32_t HALF_LINE = 16;
+                cairo_rectangle ( cr, x, y-HALF_LINE, 1, 2*HALF_LINE );
+                cairo_fill (cr);
+                cairo_rectangle ( cr, x-HALF_LINE, y, 2*HALF_LINE, 1 );
+                cairo_fill (cr);
+            }
+        }
+    }
+    else
+    {
+        /* no x/y grid for seq, timing and list diagrams*/
+    }
+
+    TRACE_END();
+}
+
+void gui_sketch_overlay_private_draw_snap_indicator( gui_sketch_overlay_t *this_,
+                                                     const gui_sketch_card_t *card_under_mouse,
+                                                     gui_sketch_snap_state_t snapped,
+                                                     int32_t x,
+                                                     int32_t y,
+                                                     cairo_t *cr )
+{
+    TRACE_BEGIN();
+    assert( NULL != card_under_mouse );
+    assert( NULL != cr );
+
+    cairo_set_source_rgba( cr,
+                           (*this_).overlay_std_red,
+                           (*this_).overlay_std_green,
+                           (*this_).overlay_std_blue,
+                           (*this_).overlay_std_alpha
+                         );
+
+    /* draw marker that position snapped to grid */
+    const shape_int_rectangle_t bounds = gui_sketch_card_get_bounds( card_under_mouse );
+    const int32_t left = shape_int_rectangle_get_left(&bounds);
+    const int32_t top = shape_int_rectangle_get_top(&bounds);
+    const int32_t width = shape_int_rectangle_get_width(&bounds);
+    const int32_t height = shape_int_rectangle_get_height(&bounds);
+    if ( ( snapped & GUI_SKETCH_SNAP_STATE_X ) == GUI_SKETCH_SNAP_STATE_X )
+    {
+        cairo_rectangle ( cr, x-2, top, 1, height );
+        cairo_fill (cr);
+        cairo_rectangle ( cr, x+2, top, 1, height );
+        cairo_fill (cr);
+    }
+    if ( ( snapped & GUI_SKETCH_SNAP_STATE_Y ) == GUI_SKETCH_SNAP_STATE_Y )
+    {
+        cairo_rectangle ( cr, left, y-2, width, 1 );
+        cairo_fill (cr);
+        cairo_rectangle ( cr, left, y+2, width, 1 );
+        cairo_fill (cr);
+    }
+
+    TRACE_END();
+}
+
 
 /*
 Copyright 2017-2022 Andreas Warnke
