@@ -22,7 +22,7 @@
 #include "set/data_visible_set.h"
 #include "set/data_stat.h"
 #include "util/geometry/geometry_rectangle.h"
-#include "util/string/utf8stringbuf.h"
+#include "utf8stringbuf/utf8stringbuf.h"
 #include <gtk/gtk.h>
 
 /*!
