@@ -2,8 +2,8 @@
 
 #include "json/json_importer.h"
 #include "u8/u8_error.h"
-#include "util/string/utf8string.h"
-#include "trace.h"
+#include "utf8stringbuf/utf8string.h"
+#include "trace/trace.h"
 #include <assert.h>
 #include <gtk/gtk.h>
 #include <stdbool.h>
