@@ -1,8 +1,8 @@
 /* File: txt_writer.c; Copyright and License: see below */
 
 #include "txt/txt_writer.h"
-#include "trace.h"
-#include "tslog.h"
+#include "trace/trace.h"
+#include "tslog/tslog.h"
 #include <stdio.h>
 #include <stdbool.h>
 #include <assert.h>
