@@ -26,8 +26,6 @@
 #include "set/data_stat.h"
 #include "data_id.h"
 #include "set/data_visible_set.h"
-#include "universal_int32_pair.h"
-#include "universal_bool_list.h"
 #include <cairo.h>
 #include <stdint.h>
 
@@ -43,6 +41,9 @@ struct pencil_diagram_maker_struct {
     pencil_classifier_composer_t classifier_painter;  /*!< own instance of a classifier painter */
     pencil_relationship_painter_t relationship_painter;  /*!< own instance of a relationship_painter */
     pencil_feature_painter_t feature_painter;  /*!< own instance of a feature_painter */
+
+    double snap_to_grid_distance;  /*!< plus/minus some pixels shall snap to grid. */
+                                   /*!< This is the expected accuracy for mouse input devices */
 };
 
 typedef struct pencil_diagram_maker_struct pencil_diagram_maker_t;
@@ -92,8 +93,8 @@ static inline void pencil_diagram_maker_define_grid ( pencil_diagram_maker_t *th
  *  \param io_layout_stat pointer to already initialized statistics object where layouting statistics are added
  *                        or NULL if no statistics of interest
  */
-static inline void pencil_diagram_maker_layout_elements ( pencil_diagram_maker_t *this_, 
-                                                          cairo_t *cr, 
+static inline void pencil_diagram_maker_layout_elements ( pencil_diagram_maker_t *this_,
+                                                          cairo_t *cr,
                                                           data_stat_t *io_layout_stat
                                                         );
 
@@ -173,9 +174,12 @@ void pencil_diagram_maker_private_draw_relationships ( pencil_diagram_maker_t *t
  *  \param this_ pointer to own object attributes
  *  \param x x-position
  *  \param y y-position
- *  \param filter a filter for object types. E.g. PENCIL_TYPE_FILTER_LIFELINE will return the classifier instead of the lifeline-feature.
- *  \param out_selected_id the object id at the given location. The id is invalid if there is no object at the given location.
- *  \param out_surrounding_id the id of the embracing object at the given location. The id is invalid if there is no object at the given location.
+ *  \param filter a filter for object types.
+ *                E.g. PENCIL_TYPE_FILTER_LIFELINE will return the classifier instead of the lifeline-feature.
+ *  \param out_selected_id the object id at the given location.
+ *                         The id is invalid if there is no object at the given location.
+ *  \param out_surrounding_id the id of the embracing object at the given location.
+ *                            The id is invalid if there is no object at the given location.
  *  \return PENCIL_ERROR_OUT_OF_BOUNDS if the given position x, y is not in the diagram.
  */
 static inline pencil_error_t pencil_diagram_maker_get_object_id_at_pos ( const pencil_diagram_maker_t *this_,
