@@ -1,9 +1,9 @@
 /* File: pencil_classifier_composer.c; Copyright and License: see below */
 
 #include "pencil_classifier_composer.h"
-#include "trace.h"
-#include "util/string/utf8stringbuf.h"
-#include "util/string/utf8string.h"
+#include "trace/trace.h"
+#include "utf8stringbuf/utf8stringbuf.h"
+#include "utf8stringbuf/utf8string.h"
 #include <pango/pangocairo.h>
 #include <stdio.h>
 #include <stdlib.h>
