@@ -1,8 +1,8 @@
 /* File: pencil_feat_label_layouter.c; Copyright and License: see below */
 
 #include "pencil_feat_label_layouter.h"
-#include "trace.h"
-#include "util/string/utf8string.h"
+#include "trace/trace.h"
+#include "utf8stringbuf/utf8string.h"
 
 void pencil_feat_label_layouter_init( pencil_feat_label_layouter_t *this_,
                                       pencil_layout_data_t *layout_data,
