@@ -1,8 +1,8 @@
 /* File: pencil_label_layout_helper.c; Copyright and License: see below */
 
 #include "pencil_label_layout_helper.h"
-#include "trace.h"
-#include "util/string/utf8string.h"
+#include "trace/trace.h"
+#include "utf8stringbuf/utf8string.h"
 
 void pencil_label_layout_helper_init( pencil_label_layout_helper_t *this_ )
 {
