@@ -3,8 +3,8 @@
 #include "pencil_rel_label_layouter.h"
 #include "util/geometry/geometry_point.h"
 #include "util/geometry/geometry_direction.h"
-#include "trace.h"
-#include "util/string/utf8string.h"
+#include "trace/trace.h"
+#include "utf8stringbuf/utf8string.h"
 
 void pencil_rel_label_layouter_init( pencil_rel_label_layouter_t *this_,
                                      pencil_layout_data_t *layout_data,
