@@ -117,7 +117,7 @@ static void test_expand_space(void)
     pencil_classifier_composer_t classifier_composer;
     pencil_classifier_composer_init( &classifier_composer );
 
-    const geometry_rectangle_t space = { .left = 100.0, .top = 90.0, .width = 420.0, .height = 104.0 };
+    const geometry_rectangle_t in_space = { .left = 100.0, .top = 90.0, .width = 420.0, .height = 104.0 };
 
     for ( unsigned int t_idx = 0; t_idx < DATA_CLASSIFIER_TYPE_COUNT; t_idx ++ )
     {
@@ -130,7 +130,7 @@ static void test_expand_space(void)
             /* run composing method */
             const int err
                 = pencil_classifier_composer_expand_space( &classifier_composer,
-                                                           &space,
+                                                           &in_space,
                                                            (show_children != 0),
                                                            &pencil_size,
                                                            font_layout,
@@ -143,11 +143,11 @@ static void test_expand_space(void)
             if ( draw_classifier_icon_is_fix_sized_symbol( &draw_classifier_icon, classifier_type ) )
             {
                 /* no intesects if fix-size-symbol */
-                TEST_ASSERT_EQUAL_DOUBLE( 0.0, geometry_rectangle_get_intersect_area( &space, symbol ) );
+                TEST_ASSERT_EQUAL_DOUBLE( 0.0, geometry_rectangle_get_intersect_area( &in_space, symbol ) );
             }
             TEST_ASSERT( ! geometry_rectangle_is_empty( symbol ) );
             const geometry_rectangle_t *const label = layout_visible_classifier_get_label_box_const( &layout_vis_classifier );
-            TEST_ASSERT_EQUAL_DOUBLE( 0.0, geometry_rectangle_get_intersect_area( &space, label ) );
+            TEST_ASSERT_EQUAL_DOUBLE( 0.0, geometry_rectangle_get_intersect_area( &in_space, label ) );
             TEST_ASSERT( ! geometry_rectangle_is_empty( label ) );
             const geometry_rectangle_t *const space = layout_visible_classifier_get_space_const( &layout_vis_classifier );
             TEST_ASSERT_EQUAL_DOUBLE( 100.0, geometry_rectangle_get_left( space ) );
